==> edge-login-ui-rn-2.12.0.tgz: package/lib/components/modals/SecurityAlertsModal.js <==
import * as React from 'react';
import { Text, TouchableOpacity } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import { sprintf } from 'sprintf-js';
import s from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler';
import { useTheme } from '../services/ThemeContext';
import { ModalScrollArea, ModalTitle } from '../themed/ModalParts';
import { ThemedModal } from '../themed/ThemedModal';
export const SecurityAlertsModal = (props) => {
    const { bridge, messages } = props;
    const theme = useTheme();
    const handleCancel = useHandler(() => bridge.resolve(undefined));
    const renderList = () => {
        const out = [];
        let isFirst = true;
        for (const message of messages) {
            const { otpResetPending, username } = message;
            if (otpResetPending && username != null) {
                out.push(renderRow(username, true, isFirst));
                isFirst = false;
            }
        }
        for (const message of messages) {
            const { pendingVouchers = [], username } = message;
            if (pendingVouchers.length > 0 && username != null) {
                out.push(renderRow(username, false, isFirst));
                isFirst = false;
            }
        }
        return out;
    };
    const renderRow = (username, isReset, isFirst) => {
        const styles = getStyles(theme);
        return (React.createElement(TouchableOpacity, { key: (isReset ? 'reset:' : 'voucher:') + username, style: isFirst ? styles.row : styles.rowBorder, onPress: () => bridge.resolve(username) },
            React.createElement(FontAwesome, { color: isReset ? theme.dangerText : theme.warningText, name: "exclamation-triangle", size: theme.rem(1.5), style: styles.rowIcon }),
            React.createElement(Text, { style: styles.rowText },
                React.createElement(Text, { style: styles.bold }, isReset
                    ? sprintf(s.strings.alert_modal_reset_s, username)
                    : sprintf(s.strings.alert_modal_voucher_s, username)),
                s.strings.alert_modal_action),
            React.createElement(AntDesignIcon, { color: theme.iconTappable, name: "right", size: theme.rem(1), style: styles.rowIcon })));
    };
    return (React.createElement(ThemedModal, { bridge: bridge, warning: true, onCancel: handleCancel },
        React.createElement(ModalTitle, null, s.strings.security_is_our_priority_modal_title),
        React.createElement(ModalScrollArea, { onCancel: handleCancel }, renderList())));
};
const getStyles = cacheStyles((theme) => ({
    row: {
        alignItems: 'center',
        flexDirection: 'row'
    },
    rowBorder: {
        alignItems: 'center',
        borderTopColor: theme.lineDivider,
        borderTopWidth: theme.thinLineWidth,
        flexDirection: 'row',
        marginTop: theme.rem(0.5),
        paddingTop: theme.rem(0.5)
    },
    rowIcon: {
        margin: theme.rem(0.5)
    },
    rowText: {
        color: theme.primaryText,
        flexGrow: 1,
        flexShrink: 1,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        margin: theme.rem(0.5)
    },
    bold: {
        fontWeight: 'bold'
    }
}));

==> edge-login-ui-rn-2.20.0.tgz: package/lib/components/modals/SecurityAlertsModal.js <==
import * as React from 'react';
import { Text, TouchableOpacity } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import { sprintf } from 'sprintf-js';
import { lstrings } from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler';
import { useTheme } from '../services/ThemeContext';
import { ModalScrollArea, ModalTitle } from '../themed/ModalParts';
import { ThemedModal } from '../themed/ThemedModal';
export const SecurityAlertsModal = (props) => {
    const { bridge, messages } = props;
    const theme = useTheme();
    const handleCancel = useHandler(() => bridge.resolve(undefined));
    const renderList = () => {
        const out = [];
        let isFirst = true;
        for (const message of messages) {
            const { otpResetPending, username } = message;
            if (otpResetPending && username != null) {
                out.push(renderRow(username, true, isFirst));
                isFirst = false;
            }
        }
        for (const message of messages) {
            const { pendingVouchers = [], username } = message;
            if (pendingVouchers.length > 0 && username != null) {
                out.push(renderRow(username, false, isFirst));
                isFirst = false;
            }
        }
        return out;
    };
    const renderRow = (username, isReset, isFirst) => {
        const styles = getStyles(theme);
        return (React.createElement(TouchableOpacity, { key: (isReset ? 'reset:' : 'voucher:') + username, style: isFirst ? styles.row : styles.rowBorder, onPress: () => bridge.resolve(username) },
            React.createElement(FontAwesome, { color: isReset ? theme.dangerText : theme.warningText, name: "exclamation-triangle", size: theme.rem(1.5), style: styles.rowIcon }),
            React.createElement(Text, { style: styles.rowText },
                React.createElement(Text, { style: styles.bold }, isReset
                    ? sprintf(lstrings.alert_modal_reset_s, username)
                    : sprintf(lstrings.alert_modal_voucher_s, username)),
                lstrings.alert_modal_action),
            React.createElement(AntDesignIcon, { color: theme.iconTappable, name: "right", size: theme.rem(1), style: styles.rowIcon })));
    };
    return (React.createElement(ThemedModal, { bridge: bridge, warning: true, onCancel: handleCancel },
        React.createElement(ModalTitle, null, lstrings.security_is_our_priority_modal_title),
        React.createElement(ModalScrollArea, null, renderList())));
};
const getStyles = cacheStyles((theme) => ({
    row: {
        alignItems: 'center',
        flexDirection: 'row'
    },
    rowBorder: {
        alignItems: 'center',
        borderTopColor: theme.lineDivider,
        borderTopWidth: theme.thinLineWidth,
        flexDirection: 'row',
        marginTop: theme.rem(0.5),
        paddingTop: theme.rem(0.5)
    },
    rowIcon: {
        margin: theme.rem(0.5)
    },
    rowText: {
        color: theme.primaryText,
        flexGrow: 1,
        flexShrink: 1,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        margin: theme.rem(0.5)
    },
    bold: {
        fontWeight: 'bold'
    }
}));
